"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IpVersion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IpVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IpVersion.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IP_VERSION_UNSPECIFIED: _IpVersion.ValueType  # 0
    IPV4: _IpVersion.ValueType  # 1
    """IPv4 address, for example 192.168.0.0."""
    IPV6: _IpVersion.ValueType  # 2
    """IPv6 address, not available yet."""

class IpVersion(_IpVersion, metaclass=_IpVersionEnumTypeWrapper): ...

IP_VERSION_UNSPECIFIED: IpVersion.ValueType  # 0
IPV4: IpVersion.ValueType  # 1
"""IPv4 address, for example 192.168.0.0."""
IPV6: IpVersion.ValueType  # 2
"""IPv6 address, not available yet."""
global___IpVersion = IpVersion

@typing.final
class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Node._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Node._Status.ValueType  # 0
        PROVISIONING: Node._Status.ValueType  # 1
        """Node instance is not yet created (e.g. in progress)."""
        NOT_CONNECTED: Node._Status.ValueType  # 2
        """Node instance is created but not registered
        (e.g. is still initializing).
        """
        NOT_READY: Node._Status.ValueType  # 3
        """Node has connected but is not ready for
        workload (see conditions for details).
        """
        READY: Node._Status.ValueType  # 4
        """Node has connected and ready for workload."""
        MISSING: Node._Status.ValueType  # 5
        """Node is still registered but its instance
        is deleted (this is our bug).
        """
        STOPPED: Node._Status.ValueType  # 6
        """Node is stopped"""
        UNKNOWN: Node._Status.ValueType  # 7
        """Backend request to kubernetes api was unsuccessful."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Computed node status."""

    STATUS_UNSPECIFIED: Node.Status.ValueType  # 0
    PROVISIONING: Node.Status.ValueType  # 1
    """Node instance is not yet created (e.g. in progress)."""
    NOT_CONNECTED: Node.Status.ValueType  # 2
    """Node instance is created but not registered
    (e.g. is still initializing).
    """
    NOT_READY: Node.Status.ValueType  # 3
    """Node has connected but is not ready for
    workload (see conditions for details).
    """
    READY: Node.Status.ValueType  # 4
    """Node has connected and ready for workload."""
    MISSING: Node.Status.ValueType  # 5
    """Node is still registered but its instance
    is deleted (this is our bug).
    """
    STOPPED: Node.Status.ValueType  # 6
    """Node is stopped"""
    UNKNOWN: Node.Status.ValueType  # 7
    """Backend request to kubernetes api was unsuccessful."""

    @typing.final
    class KubernetesStatus(google.protobuf.message.Message):
        """Kubernetes node info"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        CONDITIONS_FIELD_NUMBER: builtins.int
        TAINTS_FIELD_NUMBER: builtins.int
        ATTACHED_VOLUMES_FIELD_NUMBER: builtins.int
        id: builtins.str
        """Node id (and instance name)"""
        @property
        def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition]:
            """Conditions is an array of current observed node conditions.
            More info: https://kubernetes.io/docs/concepts/nodes/node/#condition
            """

        @property
        def taints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Taint]:
            """If specified, the node's taints."""

        @property
        def attached_volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedVolume]:
            """List of volumes that are attached to the node."""

        def __init__(
            self,
            *,
            id: builtins.str = ...,
            conditions: collections.abc.Iterable[global___Condition] | None = ...,
            taints: collections.abc.Iterable[global___Taint] | None = ...,
            attached_volumes: collections.abc.Iterable[global___AttachedVolume] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["attached_volumes", b"attached_volumes", "conditions", b"conditions", "id", b"id", "taints", b"taints"]) -> None: ...

    @typing.final
    class CloudStatus(google.protobuf.message.Message):
        """Cloud instance info"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        STATUS_MESSAGE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """Compute instance id"""
        status: builtins.str
        """IG instance status"""
        status_message: builtins.str
        """IG instance status message"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            status: builtins.str = ...,
            status_message: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "status", b"status", "status_message", b"status_message"]) -> None: ...

    @typing.final
    class Spec(google.protobuf.message.Message):
        """Node specification."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESOURCES_FIELD_NUMBER: builtins.int
        DISK_FIELD_NUMBER: builtins.int
        @property
        def resources(self) -> global___ResourcesSpec:
            """Node group specified resources."""

        @property
        def disk(self) -> global___DiskSpec:
            """Node group specified disk."""

        def __init__(
            self,
            *,
            resources: global___ResourcesSpec | None = ...,
            disk: global___DiskSpec | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disk", b"disk", "resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["disk", b"disk", "resources", b"resources"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    CLOUD_STATUS_FIELD_NUMBER: builtins.int
    KUBERNETES_STATUS_FIELD_NUMBER: builtins.int
    status: global___Node.Status.ValueType
    """Computed node status."""
    @property
    def spec(self) -> global___Node.Spec:
        """Node specificaion."""

    @property
    def cloud_status(self) -> global___Node.CloudStatus:
        """Cloud instance status.
        Not available in `MISSING` status.
        """

    @property
    def kubernetes_status(self) -> global___Node.KubernetesStatus:
        """Kubernetes node status.
        Not available in `PROVISIONING` and `NOT_CONNECTED` states.
        """

    def __init__(
        self,
        *,
        status: global___Node.Status.ValueType = ...,
        spec: global___Node.Spec | None = ...,
        cloud_status: global___Node.CloudStatus | None = ...,
        kubernetes_status: global___Node.KubernetesStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_status", b"cloud_status", "kubernetes_status", b"kubernetes_status", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_status", b"cloud_status", "kubernetes_status", b"kubernetes_status", "spec", b"spec", "status", b"status"]) -> None: ...

global___Node = Node

@typing.final
class Condition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    LAST_HEARTBEAT_TIME_FIELD_NUMBER: builtins.int
    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Type of node condition."""
    status: builtins.str
    """Status is the status of the condition."""
    message: builtins.str
    """Human-readable message indicating details about last transition."""
    @property
    def last_heartbeat_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last time we got an update on a given condition."""

    @property
    def last_transition_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last time the condition transit from one status to another."""

    def __init__(
        self,
        *,
        type: builtins.str = ...,
        status: builtins.str = ...,
        message: builtins.str = ...,
        last_heartbeat_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_transition_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["last_heartbeat_time", b"last_heartbeat_time", "last_transition_time", b"last_transition_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["last_heartbeat_time", b"last_heartbeat_time", "last_transition_time", b"last_transition_time", "message", b"message", "status", b"status", "type", b"type"]) -> None: ...

global___Condition = Condition

@typing.final
class Taint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Effect:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EffectEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Taint._Effect.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EFFECT_UNSPECIFIED: Taint._Effect.ValueType  # 0
        NO_SCHEDULE: Taint._Effect.ValueType  # 1
        """Do not allow new pods to schedule onto the node unless they tolerate the taint,
        but allow all pods submitted to Kubelet without going through the scheduler
        to start, and allow all already-running pods to continue running.
        """
        PREFER_NO_SCHEDULE: Taint._Effect.ValueType  # 2
        """Like NO_SCHEDULE, but the scheduler tries not to schedule
        new pods onto the node, rather than prohibiting new pods from scheduling
        onto the node entirely. Enforced by the scheduler.
        """
        NO_EXECUTE: Taint._Effect.ValueType  # 3
        """Evict any already-running pods that do not tolerate the taint."""

    class Effect(_Effect, metaclass=_EffectEnumTypeWrapper): ...
    EFFECT_UNSPECIFIED: Taint.Effect.ValueType  # 0
    NO_SCHEDULE: Taint.Effect.ValueType  # 1
    """Do not allow new pods to schedule onto the node unless they tolerate the taint,
    but allow all pods submitted to Kubelet without going through the scheduler
    to start, and allow all already-running pods to continue running.
    """
    PREFER_NO_SCHEDULE: Taint.Effect.ValueType  # 2
    """Like NO_SCHEDULE, but the scheduler tries not to schedule
    new pods onto the node, rather than prohibiting new pods from scheduling
    onto the node entirely. Enforced by the scheduler.
    """
    NO_EXECUTE: Taint.Effect.ValueType  # 3
    """Evict any already-running pods that do not tolerate the taint."""

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    EFFECT_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The taint key to be applied to a node."""
    value: builtins.str
    """The taint value corresponding to the taint key."""
    effect: global___Taint.Effect.ValueType
    """The effect of the taint on pods that do not tolerate the taint."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
        effect: global___Taint.Effect.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["effect", b"effect", "key", b"key", "value", b"value"]) -> None: ...

global___Taint = Taint

@typing.final
class AttachedVolume(google.protobuf.message.Message):
    """AttachedVolume describes a volume attached to a node"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRIVER_NAME_FIELD_NUMBER: builtins.int
    VOLUME_HANDLE_FIELD_NUMBER: builtins.int
    driver_name: builtins.str
    """Name of the driver which has attached the volume"""
    volume_handle: builtins.str
    """Volume handle (cloud disk id)"""
    def __init__(
        self,
        *,
        driver_name: builtins.str = ...,
        volume_handle: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["driver_name", b"driver_name", "volume_handle", b"volume_handle"]) -> None: ...

global___AttachedVolume = AttachedVolume

@typing.final
class NodeTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NetworkSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NodeTemplate.NetworkSettings._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: NodeTemplate.NetworkSettings._Type.ValueType  # 0
            STANDARD: NodeTemplate.NetworkSettings._Type.ValueType  # 1
            SOFTWARE_ACCELERATED: NodeTemplate.NetworkSettings._Type.ValueType  # 2
            """unsupported yet, commented for possible future utilization.
            HARDWARE_ACCELERATED = 3;
            """

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        TYPE_UNSPECIFIED: NodeTemplate.NetworkSettings.Type.ValueType  # 0
        STANDARD: NodeTemplate.NetworkSettings.Type.ValueType  # 1
        SOFTWARE_ACCELERATED: NodeTemplate.NetworkSettings.Type.ValueType  # 2
        """unsupported yet, commented for possible future utilization.
        HARDWARE_ACCELERATED = 3;
        """

        TYPE_FIELD_NUMBER: builtins.int
        type: global___NodeTemplate.NetworkSettings.Type.ValueType
        def __init__(
            self,
            *,
            type: global___NodeTemplate.NetworkSettings.Type.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

    @typing.final
    class ContainerRuntimeSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NodeTemplate.ContainerRuntimeSettings._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: NodeTemplate.ContainerRuntimeSettings._Type.ValueType  # 0
            DOCKER: NodeTemplate.ContainerRuntimeSettings._Type.ValueType  # 1
            CONTAINERD: NodeTemplate.ContainerRuntimeSettings._Type.ValueType  # 2

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        TYPE_UNSPECIFIED: NodeTemplate.ContainerRuntimeSettings.Type.ValueType  # 0
        DOCKER: NodeTemplate.ContainerRuntimeSettings.Type.ValueType  # 1
        CONTAINERD: NodeTemplate.ContainerRuntimeSettings.Type.ValueType  # 2

        TYPE_FIELD_NUMBER: builtins.int
        type: global___NodeTemplate.ContainerRuntimeSettings.Type.ValueType
        def __init__(
            self,
            *,
            type: global___NodeTemplate.ContainerRuntimeSettings.Type.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

    @typing.final
    class ContainerNetworkSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POD_MTU_FIELD_NUMBER: builtins.int
        pod_mtu: builtins.int
        def __init__(
            self,
            *,
            pod_mtu: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["pod_mtu", b"pod_mtu"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    BOOT_DISK_SPEC_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    SCHEDULING_POLICY_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_SPECS_FIELD_NUMBER: builtins.int
    PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    CONTAINER_RUNTIME_SETTINGS_FIELD_NUMBER: builtins.int
    CONTAINER_NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    GPU_SETTINGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the instance.
    In order to be unique it must contain at least on of instance unique placeholders:
      {instance.short_id}
      {instance.index}
      combination of {instance.zone_id} and {instance.index_in_zone}
    Example: my-instance-{instance.index}
    If not set, default is used: {instance_group.id}-{instance.short_id}
    It may also contain another placeholders, see metadata doc for full list.
    """
    platform_id: builtins.str
    """ID of the hardware platform configuration for the node."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """these labels will be assigned to compute nodes (instances), created by the nodegroup"""

    @property
    def resources_spec(self) -> global___ResourcesSpec:
        """Computing resources of the node such as the amount of memory and number of cores."""

    @property
    def boot_disk_spec(self) -> global___DiskSpec:
        """Specification for the boot disk that will be attached to the node."""

    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """The metadata as `key:value` pairs assigned to this instance template. Only SSH keys are supported as metadata.

        For more information, see [Connecting to a node over SSH](/docs/managed-kubernetes/operations/node-connect-ssh).
        """

    @property
    def v4_address_spec(self) -> global___NodeAddressSpec:
        """Specification for the create network interfaces for the node group compute instances.
        Deprecated, please use network_interface_specs.
        """

    @property
    def scheduling_policy(self) -> global___SchedulingPolicy:
        """Scheduling policy configuration."""

    @property
    def network_interface_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterfaceSpec]:
        """New api, to specify network interfaces for the node group compute instances.
        Can not be used together with 'v4_address_spec'
        """

    @property
    def placement_policy(self) -> global___PlacementPolicy: ...
    @property
    def network_settings(self) -> global___NodeTemplate.NetworkSettings:
        """this parameter allows to specify type of network acceleration used on nodes (instances)"""

    @property
    def container_runtime_settings(self) -> global___NodeTemplate.ContainerRuntimeSettings: ...
    @property
    def container_network_settings(self) -> global___NodeTemplate.ContainerNetworkSettings: ...
    @property
    def gpu_settings(self) -> global___GpuSettings:
        """GPU settings"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        platform_id: builtins.str = ...,
        resources_spec: global___ResourcesSpec | None = ...,
        boot_disk_spec: global___DiskSpec | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        v4_address_spec: global___NodeAddressSpec | None = ...,
        scheduling_policy: global___SchedulingPolicy | None = ...,
        network_interface_specs: collections.abc.Iterable[global___NetworkInterfaceSpec] | None = ...,
        placement_policy: global___PlacementPolicy | None = ...,
        network_settings: global___NodeTemplate.NetworkSettings | None = ...,
        container_runtime_settings: global___NodeTemplate.ContainerRuntimeSettings | None = ...,
        container_network_settings: global___NodeTemplate.ContainerNetworkSettings | None = ...,
        gpu_settings: global___GpuSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "container_network_settings", b"container_network_settings", "container_runtime_settings", b"container_runtime_settings", "gpu_settings", b"gpu_settings", "network_settings", b"network_settings", "placement_policy", b"placement_policy", "resources_spec", b"resources_spec", "scheduling_policy", b"scheduling_policy", "v4_address_spec", b"v4_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "container_network_settings", b"container_network_settings", "container_runtime_settings", b"container_runtime_settings", "gpu_settings", b"gpu_settings", "labels", b"labels", "metadata", b"metadata", "name", b"name", "network_interface_specs", b"network_interface_specs", "network_settings", b"network_settings", "placement_policy", b"placement_policy", "platform_id", b"platform_id", "resources_spec", b"resources_spec", "scheduling_policy", b"scheduling_policy", "v4_address_spec", b"v4_address_spec"]) -> None: ...

global___NodeTemplate = NodeTemplate

@typing.final
class GpuSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _GpuEnvironment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GpuEnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GpuSettings._GpuEnvironment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GPU_ENVIRONMENT_UNSPECIFIED: GpuSettings._GpuEnvironment.ValueType  # 0
        """Use one of the values below, depending on the default for the specific Cloud installation."""
        RUNC_DRIVERS_CUDA: GpuSettings._GpuEnvironment.ValueType  # 1
        """Use a node image with the pre-installed GPU toolkit, drivers and CUDA."""
        RUNC: GpuSettings._GpuEnvironment.ValueType  # 2
        """Use a node image with the pre-installed GPU toolkit but without drivers.
        You should install drivers on a node yourself in that case.
        There are tools to help you to do that, for example gpu-operator.
        """

    class GpuEnvironment(_GpuEnvironment, metaclass=_GpuEnvironmentEnumTypeWrapper): ...
    GPU_ENVIRONMENT_UNSPECIFIED: GpuSettings.GpuEnvironment.ValueType  # 0
    """Use one of the values below, depending on the default for the specific Cloud installation."""
    RUNC_DRIVERS_CUDA: GpuSettings.GpuEnvironment.ValueType  # 1
    """Use a node image with the pre-installed GPU toolkit, drivers and CUDA."""
    RUNC: GpuSettings.GpuEnvironment.ValueType  # 2
    """Use a node image with the pre-installed GPU toolkit but without drivers.
    You should install drivers on a node yourself in that case.
    There are tools to help you to do that, for example gpu-operator.
    """

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    GPU_ENVIRONMENT_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """GPU cluster id, that mk8s node will join."""
    gpu_environment: global___GpuSettings.GpuEnvironment.ValueType
    """GPU environment configured on node."""
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
        gpu_environment: global___GpuSettings.GpuEnvironment.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id", "gpu_environment", b"gpu_environment"]) -> None: ...

global___GpuSettings = GpuSettings

@typing.final
class NetworkInterfaceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_IDS_FIELD_NUMBER: builtins.int
    PRIMARY_V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    PRIMARY_V6_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the subnets."""

    @property
    def primary_v4_address_spec(self) -> global___NodeAddressSpec:
        """Primary IPv4 address that is assigned to the instance for this network interface."""

    @property
    def primary_v6_address_spec(self) -> global___NodeAddressSpec:
        """Primary IPv6 address that is assigned to the instance for this network interface."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of security groups."""

    def __init__(
        self,
        *,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        primary_v4_address_spec: global___NodeAddressSpec | None = ...,
        primary_v6_address_spec: global___NodeAddressSpec | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["primary_v4_address_spec", b"primary_v4_address_spec", "primary_v6_address_spec", b"primary_v6_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["primary_v4_address_spec", b"primary_v4_address_spec", "primary_v6_address_spec", b"primary_v6_address_spec", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___NetworkInterfaceSpec = NetworkInterfaceSpec

@typing.final
class NodeAddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONE_TO_ONE_NAT_SPEC_FIELD_NUMBER: builtins.int
    DNS_RECORD_SPECS_FIELD_NUMBER: builtins.int
    @property
    def one_to_one_nat_spec(self) -> global___OneToOneNatSpec:
        """One-to-one NAT configuration. Setting up one-to-one NAT ensures that public IP addresses are assigned to nodes, and therefore internet is accessible for all nodes of the node group. If the field is not set, NAT will not be set up."""

    @property
    def dns_record_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecordSpec]:
        """Internal DNS configuration."""

    def __init__(
        self,
        *,
        one_to_one_nat_spec: global___OneToOneNatSpec | None = ...,
        dns_record_specs: collections.abc.Iterable[global___DnsRecordSpec] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["one_to_one_nat_spec", b"one_to_one_nat_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dns_record_specs", b"dns_record_specs", "one_to_one_nat_spec", b"one_to_one_nat_spec"]) -> None: ...

global___NodeAddressSpec = NodeAddressSpec

@typing.final
class DnsRecordSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    PTR_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    """FQDN (required)."""
    dns_zone_id: builtins.str
    """DNS zone id (optional, if not set, private zone is used)."""
    ttl: builtins.int
    """DNS record ttl, values in 0-86400 (optional)."""
    ptr: builtins.bool
    """When set to true, also create PTR DNS record (optional)."""
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        dns_zone_id: builtins.str = ...,
        ttl: builtins.int = ...,
        ptr: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "fqdn", b"fqdn", "ptr", b"ptr", "ttl", b"ttl"]) -> None: ...

global___DnsRecordSpec = DnsRecordSpec

@typing.final
class OneToOneNatSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_VERSION_FIELD_NUMBER: builtins.int
    ip_version: global___IpVersion.ValueType
    """IP version for the public IP address."""
    def __init__(
        self,
        *,
        ip_version: global___IpVersion.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ip_version", b"ip_version"]) -> None: ...

global___OneToOneNatSpec = OneToOneNatSpec

@typing.final
class ResourcesSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    GPUS_FIELD_NUMBER: builtins.int
    memory: builtins.int
    """Amount of memory available to the node, specified in bytes."""
    cores: builtins.int
    """Number of cores available to the node."""
    core_fraction: builtins.int
    """Baseline level of CPU performance with the possibility to burst performance above that baseline level.
    This field sets baseline performance for each core.
    """
    gpus: builtins.int
    """Number of GPUs available to the node."""
    def __init__(
        self,
        *,
        memory: builtins.int = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
        gpus: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "gpus", b"gpus", "memory", b"memory"]) -> None: ...

global___ResourcesSpec = ResourcesSpec

@typing.final
class DiskSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    disk_type_id: builtins.str
    """ID of the disk type."""
    disk_size: builtins.int
    """Size of the disk, specified in bytes."""
    def __init__(
        self,
        *,
        disk_type_id: builtins.str = ...,
        disk_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id"]) -> None: ...

global___DiskSpec = DiskSpec

@typing.final
class SchedulingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    preemptible: builtins.bool
    """True for preemptible compute instances. Default value is false. Preemptible compute instances are stopped at least once every 24 hours, and can be stopped at any time
    if their resources are needed by Compute.
    For more information, see [Preemptible Virtual Machines](/docs/compute/concepts/preemptible-vm).
    """
    def __init__(
        self,
        *,
        preemptible: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["preemptible", b"preemptible"]) -> None: ...

global___SchedulingPolicy = SchedulingPolicy

@typing.final
class PlacementPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    placement_group_id: builtins.str
    """Identifier of placement group"""
    def __init__(
        self,
        *,
        placement_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["placement_group_id", b"placement_group_id"]) -> None: ...

global___PlacementPolicy = PlacementPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.monitoring.v3.downsampling_pb2
import yandex.cloud.monitoring.v3.thresholds_pb2
import yandex.cloud.monitoring.v3.unit_format_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ChartWidget(google.protobuf.message.Message):
    """Chart widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ValuesType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ValuesTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget._ValuesType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VALUES_TYPE_UNSPECIFIED: ChartWidget._ValuesType.ValueType  # 0
        VALUES_TYPE_ALL_ZEROS: ChartWidget._ValuesType.ValueType  # 1
        VALUES_TYPE_ALL_NULL: ChartWidget._ValuesType.ValueType  # 2

    class ValuesType(_ValuesType, metaclass=_ValuesTypeEnumTypeWrapper): ...
    VALUES_TYPE_UNSPECIFIED: ChartWidget.ValuesType.ValueType  # 0
    VALUES_TYPE_ALL_ZEROS: ChartWidget.ValuesType.ValueType  # 1
    VALUES_TYPE_ALL_NULL: ChartWidget.ValuesType.ValueType  # 2

    class _FreezeDuration:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FreezeDurationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget._FreezeDuration.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FREEZE_DURATION_UNSPECIFIED: ChartWidget._FreezeDuration.ValueType  # 0
        FREEZE_DURATION_HOUR: ChartWidget._FreezeDuration.ValueType  # 1
        """Last hour."""
        FREEZE_DURATION_DAY: ChartWidget._FreezeDuration.ValueType  # 2
        """Last day = last 24 hours."""
        FREEZE_DURATION_WEEK: ChartWidget._FreezeDuration.ValueType  # 3
        """Last 7 days."""
        FREEZE_DURATION_MONTH: ChartWidget._FreezeDuration.ValueType  # 4
        """Last 31 days."""

    class FreezeDuration(_FreezeDuration, metaclass=_FreezeDurationEnumTypeWrapper): ...
    FREEZE_DURATION_UNSPECIFIED: ChartWidget.FreezeDuration.ValueType  # 0
    FREEZE_DURATION_HOUR: ChartWidget.FreezeDuration.ValueType  # 1
    """Last hour."""
    FREEZE_DURATION_DAY: ChartWidget.FreezeDuration.ValueType  # 2
    """Last day = last 24 hours."""
    FREEZE_DURATION_WEEK: ChartWidget.FreezeDuration.ValueType  # 3
    """Last 7 days."""
    FREEZE_DURATION_MONTH: ChartWidget.FreezeDuration.ValueType  # 4
    """Last 31 days."""

    @typing.final
    class Queries(google.protobuf.message.Message):
        """Query settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Target(google.protobuf.message.Message):
            """Query target."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            QUERY_FIELD_NUMBER: builtins.int
            TEXT_MODE_FIELD_NUMBER: builtins.int
            HIDDEN_FIELD_NUMBER: builtins.int
            NAME_FIELD_NUMBER: builtins.int
            query: builtins.str
            """Required. Query."""
            text_mode: builtins.bool
            """Text mode."""
            hidden: builtins.bool
            """Checks that target is visible or invisible."""
            name: builtins.str
            """Name of the query."""
            def __init__(
                self,
                *,
                query: builtins.str = ...,
                text_mode: builtins.bool = ...,
                hidden: builtins.bool = ...,
                name: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["hidden", b"hidden", "name", b"name", "query", b"query", "text_mode", b"text_mode"]) -> None: ...

        TARGETS_FIELD_NUMBER: builtins.int
        DOWNSAMPLING_FIELD_NUMBER: builtins.int
        @property
        def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChartWidget.Queries.Target]:
            """Required. List of targets."""

        @property
        def downsampling(self) -> yandex.cloud.monitoring.v3.downsampling_pb2.Downsampling:
            """Required. Downsampling settings."""

        def __init__(
            self,
            *,
            targets: collections.abc.Iterable[global___ChartWidget.Queries.Target] | None = ...,
            downsampling: yandex.cloud.monitoring.v3.downsampling_pb2.Downsampling | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["downsampling", b"downsampling"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["downsampling", b"downsampling", "targets", b"targets"]) -> None: ...

    @typing.final
    class VisualizationSettings(google.protobuf.message.Message):
        """Visualization settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _VisualizationType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _VisualizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._VisualizationType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 0
            """Not specified (line by default)."""
            VISUALIZATION_TYPE_LINE: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 1
            """Line chart."""
            VISUALIZATION_TYPE_STACK: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 2
            """Stack chart."""
            VISUALIZATION_TYPE_COLUMN: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 3
            """Points as columns chart."""
            VISUALIZATION_TYPE_POINTS: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 4
            """Points."""
            VISUALIZATION_TYPE_PIE: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 5
            """Pie aggregation chart."""
            VISUALIZATION_TYPE_BARS: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 6
            """Bars aggregation chart."""
            VISUALIZATION_TYPE_DISTRIBUTION: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 7
            """Distribution aggregation chart."""
            VISUALIZATION_TYPE_HEATMAP: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 8
            """Heatmap aggregation chart."""

        class VisualizationType(_VisualizationType, metaclass=_VisualizationTypeEnumTypeWrapper):
            """Chart visualization type."""

        VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 0
        """Not specified (line by default)."""
        VISUALIZATION_TYPE_LINE: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 1
        """Line chart."""
        VISUALIZATION_TYPE_STACK: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 2
        """Stack chart."""
        VISUALIZATION_TYPE_COLUMN: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 3
        """Points as columns chart."""
        VISUALIZATION_TYPE_POINTS: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 4
        """Points."""
        VISUALIZATION_TYPE_PIE: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 5
        """Pie aggregation chart."""
        VISUALIZATION_TYPE_BARS: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 6
        """Bars aggregation chart."""
        VISUALIZATION_TYPE_DISTRIBUTION: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 7
        """Distribution aggregation chart."""
        VISUALIZATION_TYPE_HEATMAP: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 8
        """Heatmap aggregation chart."""

        class _Interpolate:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _InterpolateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._Interpolate.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            INTERPOLATE_UNSPECIFIED: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 0
            """Not specified (linear by default)."""
            INTERPOLATE_LINEAR: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 1
            """Linear."""
            INTERPOLATE_LEFT: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 2
            """Left."""
            INTERPOLATE_RIGHT: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 3
            """Right."""

        class Interpolate(_Interpolate, metaclass=_InterpolateEnumTypeWrapper): ...
        INTERPOLATE_UNSPECIFIED: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 0
        """Not specified (linear by default)."""
        INTERPOLATE_LINEAR: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 1
        """Linear."""
        INTERPOLATE_LEFT: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 2
        """Left."""
        INTERPOLATE_RIGHT: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 3
        """Right."""

        class _YaxisType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _YaxisTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._YaxisType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            YAXIS_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings._YaxisType.ValueType  # 0
            """Not specified (linear by default)."""
            YAXIS_TYPE_LINEAR: ChartWidget.VisualizationSettings._YaxisType.ValueType  # 1
            """Linear."""
            YAXIS_TYPE_LOGARITHMIC: ChartWidget.VisualizationSettings._YaxisType.ValueType  # 2
            """Logarithmic."""

        class YaxisType(_YaxisType, metaclass=_YaxisTypeEnumTypeWrapper):
            """Y axis type.
            N.B. _TYPE prefix is necessary to expect name clash with Interpolate LINEAR value.
            """

        YAXIS_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings.YaxisType.ValueType  # 0
        """Not specified (linear by default)."""
        YAXIS_TYPE_LINEAR: ChartWidget.VisualizationSettings.YaxisType.ValueType  # 1
        """Linear."""
        YAXIS_TYPE_LOGARITHMIC: ChartWidget.VisualizationSettings.YaxisType.ValueType  # 2
        """Logarithmic."""

        class _SeriesAggregation:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SeriesAggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._SeriesAggregation.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SERIES_AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 0
            """Not specified (avg by default)."""
            SERIES_AGGREGATION_AVG: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 1
            """Average."""
            SERIES_AGGREGATION_MIN: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 2
            """Minimum."""
            SERIES_AGGREGATION_MAX: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 3
            """Maximum."""
            SERIES_AGGREGATION_LAST: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 4
            """Last non-NaN value."""
            SERIES_AGGREGATION_SUM: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 5
            """Sum."""

        class SeriesAggregation(_SeriesAggregation, metaclass=_SeriesAggregationEnumTypeWrapper): ...
        SERIES_AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 0
        """Not specified (avg by default)."""
        SERIES_AGGREGATION_AVG: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 1
        """Average."""
        SERIES_AGGREGATION_MIN: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 2
        """Minimum."""
        SERIES_AGGREGATION_MAX: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 3
        """Maximum."""
        SERIES_AGGREGATION_LAST: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 4
        """Last non-NaN value."""
        SERIES_AGGREGATION_SUM: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 5
        """Sum."""

        @typing.final
        class ColorSchemeSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class AutomaticColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class StandardColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class GradientColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                GREEN_VALUE_FIELD_NUMBER: builtins.int
                YELLOW_VALUE_FIELD_NUMBER: builtins.int
                RED_VALUE_FIELD_NUMBER: builtins.int
                VIOLET_VALUE_FIELD_NUMBER: builtins.int
                green_value: builtins.str
                """Gradient green value."""
                yellow_value: builtins.str
                """Gradient yellow value."""
                red_value: builtins.str
                """Gradient red value."""
                violet_value: builtins.str
                """Gradient violet_value."""
                def __init__(
                    self,
                    *,
                    green_value: builtins.str = ...,
                    yellow_value: builtins.str = ...,
                    red_value: builtins.str = ...,
                    violet_value: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["green_value", b"green_value", "red_value", b"red_value", "violet_value", b"violet_value", "yellow_value", b"yellow_value"]) -> None: ...

            @typing.final
            class HashColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class ConstantColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                COLOR_FIELD_NUMBER: builtins.int
                color: builtins.str
                def __init__(
                    self,
                    *,
                    color: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["color", b"color"]) -> None: ...

            @typing.final
            class ThresholdsColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _Aggregation:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _AggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 0
                    AGGREGATION_LAST: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 1
                    AGGREGATION_MIN: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 2
                    AGGREGATION_MAX: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 3
                    AGGREGATION_AVG: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 4
                    AGGREGATION_SUM: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 5

                class Aggregation(_Aggregation, metaclass=_AggregationEnumTypeWrapper): ...
                AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 0
                AGGREGATION_LAST: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 1
                AGGREGATION_MIN: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 2
                AGGREGATION_MAX: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 3
                AGGREGATION_AVG: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 4
                AGGREGATION_SUM: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 5

                AGGREGATION_FIELD_NUMBER: builtins.int
                aggregation: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType
                def __init__(
                    self,
                    *,
                    aggregation: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["aggregation", b"aggregation"]) -> None: ...

            AUTOMATIC_FIELD_NUMBER: builtins.int
            STANDARD_FIELD_NUMBER: builtins.int
            GRADIENT_FIELD_NUMBER: builtins.int
            HASH_FIELD_NUMBER: builtins.int
            THRESHOLDS_FIELD_NUMBER: builtins.int
            CONSTANT_FIELD_NUMBER: builtins.int
            @property
            def automatic(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme:
                """Automatic color scheme."""

            @property
            def standard(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme:
                """Standard color scheme."""

            @property
            def gradient(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme:
                """Gradient color scheme."""

            @property
            def hash(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorScheme:
                """Hash color scheme. Based on line name or value."""

            @property
            def thresholds(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme:
                """Threshold settings color scheme."""

            @property
            def constant(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ConstantColorScheme: ...
            def __init__(
                self,
                *,
                automatic: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme | None = ...,
                standard: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme | None = ...,
                gradient: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme | None = ...,
                hash: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorScheme | None = ...,
                thresholds: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme | None = ...,
                constant: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ConstantColorScheme | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["automatic", b"automatic", "constant", b"constant", "gradient", b"gradient", "hash", b"hash", "scheme", b"scheme", "standard", b"standard", "thresholds", b"thresholds"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["automatic", b"automatic", "constant", b"constant", "gradient", b"gradient", "hash", b"hash", "scheme", b"scheme", "standard", b"standard", "thresholds", b"thresholds"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["scheme", b"scheme"]) -> typing.Literal["automatic", "standard", "gradient", "hash", "thresholds", "constant"] | None: ...

        @typing.final
        class HeatmapSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            GREEN_VALUE_FIELD_NUMBER: builtins.int
            YELLOW_VALUE_FIELD_NUMBER: builtins.int
            RED_VALUE_FIELD_NUMBER: builtins.int
            VIOLET_VALUE_FIELD_NUMBER: builtins.int
            green_value: builtins.str
            """Heatmap green value."""
            yellow_value: builtins.str
            """Heatmap yellow value."""
            red_value: builtins.str
            """Heatmap red value."""
            violet_value: builtins.str
            """Heatmap violet_value."""
            def __init__(
                self,
                *,
                green_value: builtins.str = ...,
                yellow_value: builtins.str = ...,
                red_value: builtins.str = ...,
                violet_value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["green_value", b"green_value", "red_value", b"red_value", "violet_value", b"violet_value", "yellow_value", b"yellow_value"]) -> None: ...

        @typing.final
        class Yaxis(google.protobuf.message.Message):
            """Y axis settings."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TYPE_FIELD_NUMBER: builtins.int
            TITLE_FIELD_NUMBER: builtins.int
            MIN_FIELD_NUMBER: builtins.int
            MAX_FIELD_NUMBER: builtins.int
            UNIT_FORMAT_FIELD_NUMBER: builtins.int
            PRECISION_FIELD_NUMBER: builtins.int
            type: global___ChartWidget.VisualizationSettings.YaxisType.ValueType
            """Type."""
            title: builtins.str
            """Title or empty."""
            min: builtins.str
            """Min value in extended number format or empty."""
            max: builtins.str
            """Max value in extended number format or empty."""
            unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType
            """Unit format."""
            @property
            def precision(self) -> google.protobuf.wrappers_pb2.Int64Value:
                """Tick value precision (null as default, 0-7 in other cases)."""

            def __init__(
                self,
                *,
                type: global___ChartWidget.VisualizationSettings.YaxisType.ValueType = ...,
                title: builtins.str = ...,
                min: builtins.str = ...,
                max: builtins.str = ...,
                unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType = ...,
                precision: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["precision", b"precision"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["max", b"max", "min", b"min", "precision", b"precision", "title", b"title", "type", b"type", "unit_format", b"unit_format"]) -> None: ...

        @typing.final
        class YaxisSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            LEFT_FIELD_NUMBER: builtins.int
            RIGHT_FIELD_NUMBER: builtins.int
            @property
            def left(self) -> global___ChartWidget.VisualizationSettings.Yaxis:
                """Left Y axis settings."""

            @property
            def right(self) -> global___ChartWidget.VisualizationSettings.Yaxis:
                """Right Y axis settings."""

            def __init__(
                self,
                *,
                left: global___ChartWidget.VisualizationSettings.Yaxis | None = ...,
                right: global___ChartWidget.VisualizationSettings.Yaxis | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["left", b"left", "right", b"right"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["left", b"left", "right", b"right"]) -> None: ...

        TYPE_FIELD_NUMBER: builtins.int
        NORMALIZE_FIELD_NUMBER: builtins.int
        INTERPOLATE_FIELD_NUMBER: builtins.int
        AGGREGATION_FIELD_NUMBER: builtins.int
        COLOR_SCHEME_SETTINGS_FIELD_NUMBER: builtins.int
        HEATMAP_SETTINGS_FIELD_NUMBER: builtins.int
        YAXIS_SETTINGS_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        SHOW_LABELS_FIELD_NUMBER: builtins.int
        type: global___ChartWidget.VisualizationSettings.VisualizationType.ValueType
        """Visualization type."""
        normalize: builtins.bool
        """Normalize."""
        interpolate: global___ChartWidget.VisualizationSettings.Interpolate.ValueType
        """Interpolate."""
        aggregation: global___ChartWidget.VisualizationSettings.SeriesAggregation.ValueType
        """Aggregation."""
        title: builtins.str
        """Inside chart title."""
        show_labels: builtins.bool
        """Show chart labels."""
        @property
        def color_scheme_settings(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings:
            """Color scheme settings."""

        @property
        def heatmap_settings(self) -> global___ChartWidget.VisualizationSettings.HeatmapSettings:
            """Heatmap settings."""

        @property
        def yaxis_settings(self) -> global___ChartWidget.VisualizationSettings.YaxisSettings:
            """Y axis settings."""

        def __init__(
            self,
            *,
            type: global___ChartWidget.VisualizationSettings.VisualizationType.ValueType = ...,
            normalize: builtins.bool = ...,
            interpolate: global___ChartWidget.VisualizationSettings.Interpolate.ValueType = ...,
            aggregation: global___ChartWidget.VisualizationSettings.SeriesAggregation.ValueType = ...,
            color_scheme_settings: global___ChartWidget.VisualizationSettings.ColorSchemeSettings | None = ...,
            heatmap_settings: global___ChartWidget.VisualizationSettings.HeatmapSettings | None = ...,
            yaxis_settings: global___ChartWidget.VisualizationSettings.YaxisSettings | None = ...,
            title: builtins.str = ...,
            show_labels: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["color_scheme_settings", b"color_scheme_settings", "heatmap_settings", b"heatmap_settings", "yaxis_settings", b"yaxis_settings"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["aggregation", b"aggregation", "color_scheme_settings", b"color_scheme_settings", "heatmap_settings", b"heatmap_settings", "interpolate", b"interpolate", "normalize", b"normalize", "show_labels", b"show_labels", "title", b"title", "type", b"type", "yaxis_settings", b"yaxis_settings"]) -> None: ...

    @typing.final
    class SeriesOverrides(google.protobuf.message.Message):
        """Series override settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _YaxisPosition:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _YaxisPositionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.SeriesOverrides._YaxisPosition.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            YAXIS_POSITION_UNSPECIFIED: ChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 0
            """Not specified (left by default)."""
            YAXIS_POSITION_LEFT: ChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 1
            """Left."""
            YAXIS_POSITION_RIGHT: ChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 2
            """Right."""

        class YaxisPosition(_YaxisPosition, metaclass=_YaxisPositionEnumTypeWrapper): ...
        YAXIS_POSITION_UNSPECIFIED: ChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 0
        """Not specified (left by default)."""
        YAXIS_POSITION_LEFT: ChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 1
        """Left."""
        YAXIS_POSITION_RIGHT: ChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 2
        """Right."""

        class _SeriesVisualizationType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SeriesVisualizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SERIES_VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 0
            """Not specified (line by default)."""
            SERIES_VISUALIZATION_TYPE_LINE: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 1
            """Line chart."""
            SERIES_VISUALIZATION_TYPE_STACK: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 2
            """Stack chart."""
            SERIES_VISUALIZATION_TYPE_COLUMN: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 3
            """Points as columns chart."""
            SERIES_VISUALIZATION_TYPE_POINTS: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 4
            """Points."""

        class SeriesVisualizationType(_SeriesVisualizationType, metaclass=_SeriesVisualizationTypeEnumTypeWrapper): ...
        SERIES_VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 0
        """Not specified (line by default)."""
        SERIES_VISUALIZATION_TYPE_LINE: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 1
        """Line chart."""
        SERIES_VISUALIZATION_TYPE_STACK: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 2
        """Stack chart."""
        SERIES_VISUALIZATION_TYPE_COLUMN: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 3
        """Points as columns chart."""
        SERIES_VISUALIZATION_TYPE_POINTS: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 4
        """Points."""

        @typing.final
        class SeriesOverrideSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _LineStyle:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _LineStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                LINE_STYLE_UNSPECIFIED: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 0
                LINE_STYLE_SOLID: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 1
                LINE_STYLE_DASH: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 2
                LINE_STYLE_DOTS: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 3

            class LineStyle(_LineStyle, metaclass=_LineStyleEnumTypeWrapper): ...
            LINE_STYLE_UNSPECIFIED: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 0
            LINE_STYLE_SOLID: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 1
            LINE_STYLE_DASH: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 2
            LINE_STYLE_DOTS: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 3

            NAME_FIELD_NUMBER: builtins.int
            COLOR_FIELD_NUMBER: builtins.int
            TYPE_FIELD_NUMBER: builtins.int
            STACK_NAME_FIELD_NUMBER: builtins.int
            GROW_DOWN_FIELD_NUMBER: builtins.int
            YAXIS_POSITION_FIELD_NUMBER: builtins.int
            LINE_WIDTH_FIELD_NUMBER: builtins.int
            LINE_STYLE_FIELD_NUMBER: builtins.int
            name: builtins.str
            """Series name or empty."""
            color: builtins.str
            """Series color or empty."""
            type: global___ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType
            """Type."""
            stack_name: builtins.str
            """Stack name or empty."""
            grow_down: builtins.bool
            """Stack grow down."""
            yaxis_position: global___ChartWidget.SeriesOverrides.YaxisPosition.ValueType
            """Yaxis position."""
            line_width: builtins.int
            """Line Border Width"""
            line_style: global___ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                color: builtins.str = ...,
                type: global___ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType = ...,
                stack_name: builtins.str = ...,
                grow_down: builtins.bool = ...,
                yaxis_position: global___ChartWidget.SeriesOverrides.YaxisPosition.ValueType = ...,
                line_width: builtins.int = ...,
                line_style: global___ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["color", b"color", "grow_down", b"grow_down", "line_style", b"line_style", "line_width", b"line_width", "name", b"name", "stack_name", b"stack_name", "type", b"type", "yaxis_position", b"yaxis_position"]) -> None: ...

        NAME_FIELD_NUMBER: builtins.int
        TARGET_INDEX_FIELD_NUMBER: builtins.int
        SETTINGS_FIELD_NUMBER: builtins.int
        OVERRIDE_NAME_FIELD_NUMBER: builtins.int
        MATCHER_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Series name."""
        target_index: builtins.str
        """Target index."""
        override_name: builtins.str
        @property
        def settings(self) -> global___ChartWidget.SeriesOverrides.SeriesOverrideSettings:
            """Required. Override settings."""

        @property
        def matcher(self) -> global___ChartWidget.OverrideMatcher: ...
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            target_index: builtins.str = ...,
            settings: global___ChartWidget.SeriesOverrides.SeriesOverrideSettings | None = ...,
            override_name: builtins.str = ...,
            matcher: global___ChartWidget.OverrideMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["matcher", b"matcher", "name", b"name", "settings", b"settings", "target_index", b"target_index", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["matcher", b"matcher", "name", b"name", "override_name", b"override_name", "settings", b"settings", "target_index", b"target_index", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["name", "target_index"] | None: ...

    @typing.final
    class OverrideMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        QUERY_FIELD_NUMBER: builtins.int
        LINE_FIELD_NUMBER: builtins.int
        REGEXP_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        @property
        def query(self) -> global___ChartWidget.QueryMatcher: ...
        @property
        def line(self) -> global___ChartWidget.LineMatcher: ...
        @property
        def regexp(self) -> global___ChartWidget.RegExpMatcher: ...
        @property
        def values(self) -> global___ChartWidget.ValueMatcher: ...
        def __init__(
            self,
            *,
            query: global___ChartWidget.QueryMatcher | None = ...,
            line: global___ChartWidget.LineMatcher | None = ...,
            regexp: global___ChartWidget.RegExpMatcher | None = ...,
            values: global___ChartWidget.ValueMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["line", b"line", "query", b"query", "regexp", b"regexp", "type", b"type", "values", b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["line", b"line", "query", b"query", "regexp", b"regexp", "type", b"type", "values", b"values"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["query", "line", "regexp", "values"] | None: ...

    @typing.final
    class QueryMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAMES_FIELD_NUMBER: builtins.int
        @property
        def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            names: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["names", b"names"]) -> None: ...

    @typing.final
    class LineMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINE_IDS_FIELD_NUMBER: builtins.int
        @property
        def line_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            line_ids: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["line_ids", b"line_ids"]) -> None: ...

    @typing.final
    class RegExpMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REG_EXP_FIELD_NUMBER: builtins.int
        reg_exp: builtins.str
        def __init__(
            self,
            *,
            reg_exp: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["reg_exp", b"reg_exp"]) -> None: ...

    @typing.final
    class ValueMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VALUE_TYPE_FIELD_NUMBER: builtins.int
        value_type: global___ChartWidget.ValuesType.ValueType
        def __init__(
            self,
            *,
            value_type: global___ChartWidget.ValuesType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["value_type", b"value_type"]) -> None: ...

    @typing.final
    class NameHidingSettings(google.protobuf.message.Message):
        """Name hiding settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POSITIVE_FIELD_NUMBER: builtins.int
        NAMES_FIELD_NUMBER: builtins.int
        positive: builtins.bool
        """True if we want to show concrete series names only, false if we want to hide concrete series names."""
        @property
        def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Series names to show or hide."""

        def __init__(
            self,
            *,
            positive: builtins.bool = ...,
            names: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["names", b"names", "positive", b"positive"]) -> None: ...

    @typing.final
    class RepeatSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPEAT_BY_FIELD_NUMBER: builtins.int
        MAX_CHARTS_IN_ROW_FIELD_NUMBER: builtins.int
        max_charts_in_row: builtins.int
        """Max number of chart in one row."""
        @property
        def repeat_by(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Parameters to repeat by."""

        def __init__(
            self,
            *,
            repeat_by: collections.abc.Iterable[builtins.str] | None = ...,
            max_charts_in_row: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["max_charts_in_row", b"max_charts_in_row", "repeat_by", b"repeat_by"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    QUERIES_FIELD_NUMBER: builtins.int
    VISUALIZATION_SETTINGS_FIELD_NUMBER: builtins.int
    SERIES_OVERRIDES_FIELD_NUMBER: builtins.int
    NAME_HIDING_SETTINGS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DISPLAY_LEGEND_FIELD_NUMBER: builtins.int
    FREEZE_FIELD_NUMBER: builtins.int
    REPEAT_FIELD_NUMBER: builtins.int
    THRESHOLDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. Chart ID."""
    description: builtins.str
    """Chart description in dashboard (not enabled in UI)."""
    title: builtins.str
    """Chart widget title."""
    display_legend: builtins.bool
    """Enable legend under chart."""
    freeze: global___ChartWidget.FreezeDuration.ValueType
    """Fixed time interval for chart."""
    @property
    def queries(self) -> global___ChartWidget.Queries:
        """Queries."""

    @property
    def visualization_settings(self) -> global___ChartWidget.VisualizationSettings:
        """Visualization settings."""

    @property
    def series_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChartWidget.SeriesOverrides]:
        """Override settings."""

    @property
    def name_hiding_settings(self) -> global___ChartWidget.NameHidingSettings:
        """Name hiding settings."""

    @property
    def repeat(self) -> global___ChartWidget.RepeatSettings:
        """Setting for repeat panel / repeat row"""

    @property
    def thresholds(self) -> yandex.cloud.monitoring.v3.thresholds_pb2.Thresholds:
        """Threshold settings"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        queries: global___ChartWidget.Queries | None = ...,
        visualization_settings: global___ChartWidget.VisualizationSettings | None = ...,
        series_overrides: collections.abc.Iterable[global___ChartWidget.SeriesOverrides] | None = ...,
        name_hiding_settings: global___ChartWidget.NameHidingSettings | None = ...,
        description: builtins.str = ...,
        title: builtins.str = ...,
        display_legend: builtins.bool = ...,
        freeze: global___ChartWidget.FreezeDuration.ValueType = ...,
        repeat: global___ChartWidget.RepeatSettings | None = ...,
        thresholds: yandex.cloud.monitoring.v3.thresholds_pb2.Thresholds | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name_hiding_settings", b"name_hiding_settings", "queries", b"queries", "repeat", b"repeat", "thresholds", b"thresholds", "visualization_settings", b"visualization_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "display_legend", b"display_legend", "freeze", b"freeze", "id", b"id", "name_hiding_settings", b"name_hiding_settings", "queries", b"queries", "repeat", b"repeat", "series_overrides", b"series_overrides", "thresholds", b"thresholds", "title", b"title", "visualization_settings", b"visualization_settings"]) -> None: ...

global___ChartWidget = ChartWidget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.group_pb2
import yandex.cloud.organizationmanager.v1.group_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class GroupServiceStub:
    """A set of methods for managing groups."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.GetGroupRequest,
        yandex.cloud.organizationmanager.v1.group_pb2.Group,
    ]
    """Returns the specified Group resource.

    To get the list of available Group resources, make a [List] request.
    """

    ResolveExternal: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ResolveExternalGroupRequest,
        yandex.cloud.organizationmanager.v1.group_pb2.Group,
    ]
    """Returns external group by subject container and external id"""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsResponse,
    ]
    """Retrieves the list of group resources."""

    ListExternal: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsResponse,
    ]
    """Retrieves the list of external group linked subject container"""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.CreateGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a group in the specified organization."""

    CreateExternal: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.CreateExternalGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an external group."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.UpdateGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified group."""

    ConvertToExternal: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ConvertToExternalGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Converts single basic (not external) group to external. Precondition: group must be basic."""

    ConvertAllToBasic: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ConvertAllToBasicGroupsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Converts all groups that belongs to subject container from external to basic (not external)."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.DeleteGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified group."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsResponse,
    ]
    """Lists operations for the specified group."""

    ListMembers: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersResponse,
    ]
    """members

    List group active members.
    """

    UpdateMembers: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.UpdateGroupMembersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update group members."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified group.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified group."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified group."""

class GroupServiceAsyncStub:
    """A set of methods for managing groups."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.GetGroupRequest,
        yandex.cloud.organizationmanager.v1.group_pb2.Group,
    ]
    """Returns the specified Group resource.

    To get the list of available Group resources, make a [List] request.
    """

    ResolveExternal: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ResolveExternalGroupRequest,
        yandex.cloud.organizationmanager.v1.group_pb2.Group,
    ]
    """Returns external group by subject container and external id"""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsResponse,
    ]
    """Retrieves the list of group resources."""

    ListExternal: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsResponse,
    ]
    """Retrieves the list of external group linked subject container"""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.CreateGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a group in the specified organization."""

    CreateExternal: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.CreateExternalGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an external group."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.UpdateGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified group."""

    ConvertToExternal: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ConvertToExternalGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Converts single basic (not external) group to external. Precondition: group must be basic."""

    ConvertAllToBasic: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ConvertAllToBasicGroupsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Converts all groups that belongs to subject container from external to basic (not external)."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.DeleteGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified group."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsResponse,
    ]
    """Lists operations for the specified group."""

    ListMembers: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersRequest,
        yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersResponse,
    ]
    """members

    List group active members.
    """

    UpdateMembers: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_service_pb2.UpdateGroupMembersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update group members."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified group.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified group."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified group."""

class GroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing groups."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.GetGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_pb2.Group, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_pb2.Group]]:
        """Returns the specified Group resource.

        To get the list of available Group resources, make a [List] request.
        """

    @abc.abstractmethod
    def ResolveExternal(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ResolveExternalGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_pb2.Group, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_pb2.Group]]:
        """Returns external group by subject container and external id"""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupsResponse]]:
        """Retrieves the list of group resources."""

    @abc.abstractmethod
    def ListExternal(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_service_pb2.ListExternalGroupsResponse]]:
        """Retrieves the list of external group linked subject container"""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.CreateGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a group in the specified organization."""

    @abc.abstractmethod
    def CreateExternal(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.CreateExternalGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an external group."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.UpdateGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified group."""

    @abc.abstractmethod
    def ConvertToExternal(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ConvertToExternalGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Converts single basic (not external) group to external. Precondition: group must be basic."""

    @abc.abstractmethod
    def ConvertAllToBasic(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ConvertAllToBasicGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Converts all groups that belongs to subject container from external to basic (not external)."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.DeleteGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified group."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupOperationsResponse]]:
        """Lists operations for the specified group."""

    @abc.abstractmethod
    def ListMembers(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_service_pb2.ListGroupMembersResponse]]:
        """members

        List group active members.
        """

    @abc.abstractmethod
    def UpdateMembers(
        self,
        request: yandex.cloud.organizationmanager.v1.group_service_pb2.UpdateGroupMembersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update group members."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the specified group.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified group."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified group."""

def add_GroupServiceServicer_to_server(servicer: GroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.loadbalancer.v1.health_check_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IpVersion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IpVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IpVersion.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IP_VERSION_UNSPECIFIED: _IpVersion.ValueType  # 0
    IPV4: _IpVersion.ValueType  # 1
    """IPv4"""
    IPV6: _IpVersion.ValueType  # 2
    """IPv6"""

class IpVersion(_IpVersion, metaclass=_IpVersionEnumTypeWrapper):
    """IP version of the addresses that the load balancer works with.
    Only IPv4 is currently available.
    """

IP_VERSION_UNSPECIFIED: IpVersion.ValueType  # 0
IPV4: IpVersion.ValueType  # 1
"""IPv4"""
IPV6: IpVersion.ValueType  # 2
"""IPv6"""
global___IpVersion = IpVersion

@typing.final
class NetworkLoadBalancer(google.protobuf.message.Message):
    """A NetworkLoadBalancer resource. For more information, see [Network Load Balancer](/docs/network-load-balancer/concepts)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NetworkLoadBalancer._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: NetworkLoadBalancer._Status.ValueType  # 0
        CREATING: NetworkLoadBalancer._Status.ValueType  # 1
        """Network load balancer is being created."""
        STARTING: NetworkLoadBalancer._Status.ValueType  # 2
        """Network load balancer is being started."""
        ACTIVE: NetworkLoadBalancer._Status.ValueType  # 3
        """Network load balancer is active and sends traffic to the targets."""
        STOPPING: NetworkLoadBalancer._Status.ValueType  # 4
        """Network load balancer is being stopped."""
        STOPPED: NetworkLoadBalancer._Status.ValueType  # 5
        """Network load balancer is stopped and doesn't send traffic to the targets."""
        DELETING: NetworkLoadBalancer._Status.ValueType  # 6
        """Network load balancer is being deleted."""
        INACTIVE: NetworkLoadBalancer._Status.ValueType  # 7
        """The load balancer doesn't have any listeners or target groups, or
        attached target groups are empty. The load balancer doesn't perform any health checks or
        send traffic in this state.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: NetworkLoadBalancer.Status.ValueType  # 0
    CREATING: NetworkLoadBalancer.Status.ValueType  # 1
    """Network load balancer is being created."""
    STARTING: NetworkLoadBalancer.Status.ValueType  # 2
    """Network load balancer is being started."""
    ACTIVE: NetworkLoadBalancer.Status.ValueType  # 3
    """Network load balancer is active and sends traffic to the targets."""
    STOPPING: NetworkLoadBalancer.Status.ValueType  # 4
    """Network load balancer is being stopped."""
    STOPPED: NetworkLoadBalancer.Status.ValueType  # 5
    """Network load balancer is stopped and doesn't send traffic to the targets."""
    DELETING: NetworkLoadBalancer.Status.ValueType  # 6
    """Network load balancer is being deleted."""
    INACTIVE: NetworkLoadBalancer.Status.ValueType  # 7
    """The load balancer doesn't have any listeners or target groups, or
    attached target groups are empty. The load balancer doesn't perform any health checks or
    send traffic in this state.
    """

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NetworkLoadBalancer._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: NetworkLoadBalancer._Type.ValueType  # 0
        EXTERNAL: NetworkLoadBalancer._Type.ValueType  # 1
        """External network load balancer."""
        INTERNAL: NetworkLoadBalancer._Type.ValueType  # 2
        """Internal network load balancer."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: NetworkLoadBalancer.Type.ValueType  # 0
    EXTERNAL: NetworkLoadBalancer.Type.ValueType  # 1
    """External network load balancer."""
    INTERNAL: NetworkLoadBalancer.Type.ValueType  # 2
    """Internal network load balancer."""

    class _SessionAffinity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SessionAffinityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NetworkLoadBalancer._SessionAffinity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SESSION_AFFINITY_UNSPECIFIED: NetworkLoadBalancer._SessionAffinity.ValueType  # 0
        CLIENT_IP_PORT_PROTO: NetworkLoadBalancer._SessionAffinity.ValueType  # 1
        """5-tuple affinity."""

    class SessionAffinity(_SessionAffinity, metaclass=_SessionAffinityEnumTypeWrapper):
        """Type of session affinity. Only 5-tuple affinity is currently available.
        For more information, see [Load Balancer concepts](/docs/network-load-balancer/concepts/).
        """

    SESSION_AFFINITY_UNSPECIFIED: NetworkLoadBalancer.SessionAffinity.ValueType  # 0
    CLIENT_IP_PORT_PROTO: NetworkLoadBalancer.SessionAffinity.ValueType  # 1
    """5-tuple affinity."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SESSION_AFFINITY_FIELD_NUMBER: builtins.int
    LISTENERS_FIELD_NUMBER: builtins.int
    ATTACHED_TARGET_GROUPS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ALLOW_ZONAL_SHIFT_FIELD_NUMBER: builtins.int
    DISABLE_ZONE_STATUSES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the network load balancer."""
    folder_id: builtins.str
    """ID of the folder that the network load balancer belongs to."""
    name: builtins.str
    """Name of the network load balancer. The name is unique within the folder. 3-63 characters long."""
    description: builtins.str
    """Optional description of the network load balancer. 0-256 characters long."""
    region_id: builtins.str
    """ID of the region that the network load balancer belongs to."""
    status: global___NetworkLoadBalancer.Status.ValueType
    """Status of the network load balancer."""
    type: global___NetworkLoadBalancer.Type.ValueType
    """Type of the network load balancer. Only external network load balancers are available now."""
    session_affinity: global___NetworkLoadBalancer.SessionAffinity.ValueType
    """Type of the session affinity. Only 5-tuple affinity is available now."""
    deletion_protection: builtins.bool
    """Specifies if network load balancer protected from deletion."""
    allow_zonal_shift: builtins.bool
    """Specifies if network load balancer available to zonal shift."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Listener]:
        """List of listeners for the network load balancer."""

    @property
    def attached_target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedTargetGroup]:
        """List of target groups attached to the network load balancer."""

    @property
    def disable_zone_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DisableZoneStatus]:
        """List of disabled zones for the network load balancer."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        region_id: builtins.str = ...,
        status: global___NetworkLoadBalancer.Status.ValueType = ...,
        type: global___NetworkLoadBalancer.Type.ValueType = ...,
        session_affinity: global___NetworkLoadBalancer.SessionAffinity.ValueType = ...,
        listeners: collections.abc.Iterable[global___Listener] | None = ...,
        attached_target_groups: collections.abc.Iterable[global___AttachedTargetGroup] | None = ...,
        deletion_protection: builtins.bool = ...,
        allow_zonal_shift: builtins.bool = ...,
        disable_zone_statuses: collections.abc.Iterable[global___DisableZoneStatus] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_zonal_shift", b"allow_zonal_shift", "attached_target_groups", b"attached_target_groups", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "disable_zone_statuses", b"disable_zone_statuses", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "listeners", b"listeners", "name", b"name", "region_id", b"region_id", "session_affinity", b"session_affinity", "status", b"status", "type", b"type"]) -> None: ...

global___NetworkLoadBalancer = NetworkLoadBalancer

@typing.final
class AttachedTargetGroup(google.protobuf.message.Message):
    """An AttachedTargetGroup resource. For more information, see [Targets and groups](/docs/network-load-balancer/concepts/target-resources)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    HEALTH_CHECKS_FIELD_NUMBER: builtins.int
    target_group_id: builtins.str
    """ID of the target group."""
    @property
    def health_checks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadbalancer.v1.health_check_pb2.HealthCheck]:
        """A health check to perform on the target group.
        For now we accept only one health check per AttachedTargetGroup.
        """

    def __init__(
        self,
        *,
        target_group_id: builtins.str = ...,
        health_checks: collections.abc.Iterable[yandex.cloud.loadbalancer.v1.health_check_pb2.HealthCheck] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health_checks", b"health_checks", "target_group_id", b"target_group_id"]) -> None: ...

global___AttachedTargetGroup = AttachedTargetGroup

@typing.final
class Listener(google.protobuf.message.Message):
    """A Listener resource. For more information, see [Listener](/docs/network-load-balancer/concepts/listener)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Protocol:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Listener._Protocol.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROTOCOL_UNSPECIFIED: Listener._Protocol.ValueType  # 0
        TCP: Listener._Protocol.ValueType  # 1
        UDP: Listener._Protocol.ValueType  # 2

    class Protocol(_Protocol, metaclass=_ProtocolEnumTypeWrapper):
        """Network protocol to use."""

    PROTOCOL_UNSPECIFIED: Listener.Protocol.ValueType  # 0
    TCP: Listener.Protocol.ValueType  # 1
    UDP: Listener.Protocol.ValueType  # 2

    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the listener. The name must be unique for each listener on a single load balancer. 3-63 characters long."""
    address: builtins.str
    """IP address for the listener."""
    port: builtins.int
    """Port."""
    protocol: global___Listener.Protocol.ValueType
    """Network protocol for incoming traffic."""
    target_port: builtins.int
    """Port of a target."""
    subnet_id: builtins.str
    """ID of the subnet."""
    ip_version: global___IpVersion.ValueType
    """IP version of the external address."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        address: builtins.str = ...,
        port: builtins.int = ...,
        protocol: global___Listener.Protocol.ValueType = ...,
        target_port: builtins.int = ...,
        subnet_id: builtins.str = ...,
        ip_version: global___IpVersion.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "ip_version", b"ip_version", "name", b"name", "port", b"port", "protocol", b"protocol", "subnet_id", b"subnet_id", "target_port", b"target_port"]) -> None: ...

global___Listener = Listener

@typing.final
class TargetState(google.protobuf.message.Message):
    """State of the target that was returned after the last health check."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TargetState._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: TargetState._Status.ValueType  # 0
        INITIAL: TargetState._Status.ValueType  # 1
        """The network load balancer is setting up health checks for this target."""
        HEALTHY: TargetState._Status.ValueType  # 2
        """Health check passed and the target is ready to receive traffic."""
        UNHEALTHY: TargetState._Status.ValueType  # 3
        """Health check failed and the target is not receiving traffic."""
        DRAINING: TargetState._Status.ValueType  # 4
        """Target is being deleted and the network load balancer is no longer sending traffic to this target."""
        INACTIVE: TargetState._Status.ValueType  # 5
        """The network load balancer is stopped and not performing health checks on this target."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of the target."""

    STATUS_UNSPECIFIED: TargetState.Status.ValueType  # 0
    INITIAL: TargetState.Status.ValueType  # 1
    """The network load balancer is setting up health checks for this target."""
    HEALTHY: TargetState.Status.ValueType  # 2
    """Health check passed and the target is ready to receive traffic."""
    UNHEALTHY: TargetState.Status.ValueType  # 3
    """Health check failed and the target is not receiving traffic."""
    DRAINING: TargetState.Status.ValueType  # 4
    """Target is being deleted and the network load balancer is no longer sending traffic to this target."""
    INACTIVE: TargetState.Status.ValueType  # 5
    """The network load balancer is stopped and not performing health checks on this target."""

    SUBNET_ID_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ZONE_SHIFTED_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the subnet that the target is connected to."""
    address: builtins.str
    """IP address of the target."""
    status: global___TargetState.Status.ValueType
    """Status of the target."""
    zone_shifted: builtins.bool
    """Zone shifted status."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
        address: builtins.str = ...,
        status: global___TargetState.Status.ValueType = ...,
        zone_shifted: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "status", b"status", "subnet_id", b"subnet_id", "zone_shifted", b"zone_shifted"]) -> None: ...

global___TargetState = TargetState

@typing.final
class DisableZoneStatus(google.protobuf.message.Message):
    """Status of the disabled zone."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    DISABLED_UNTIL_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of zone."""
    @property
    def disabled_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp until which the zone will be disabled.
        If not present then zone will be disabled until it is removed through a separate call.
        """

    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        disabled_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disabled_until", b"disabled_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disabled_until", b"disabled_until", "zone_id", b"zone_id"]) -> None: ...

global___DisableZoneStatus = DisableZoneStatus
